@@ -35,17 +35,3 @@ def predict_themes(content: str) -> list:
     )
     resp.raise_for_status()
     return resp.json()['result']
-
-
-@retry_rest_api
-def get_data_custom_tags(data_source: str, id: str) -> list:
-    resp = requests.get(
-        f'{YURI_API_HOST}/analysis/api/simple-search/data-custom-tags',
-        params={
-            'data_source': data_source,
-            'id': id,
-        },
-        timeout=20,
-    )
-    resp.raise_for_status()
-    return resp.json()['data']
